<?php

class View {
	
	static function page($subj) 
	{
		$view = Def::get_view($subj);
		
		$data = Data::get($subj, $view['where']);
		if (!$data) {
			header(H_404);
			exit('<center><h1>' . H_404);
		}
		$title = $subj;
		$method = 'table';
		if ($view['full_key']) {
			$method = 'item';
			$title .= ': ' . $view['full_key'];
		}
		if (!method_exists('View', $method)) $method = 'table';
		
		$body = call_user_func('View::' . $method, $data, $subj);
		$files = Def::fw_files();
		$footer = '<div class="menu"><span class="label">source code</span>' . View::menu($files['fileList'], CR) . '</div>';
		$title = e($title);
		$head = View::head($title);
		$main_menu = View::build_main_menu();
		
		print <<<TPL
{$head}
<body>
	<div class="page">
		<p>{$main_menu}</p>
		<h1>{$title}</h1>
		{$body}
		<div class="footer">{$footer}</div>
		<div class="footer"><div class="menu">
			<a href="http://ir2.ru/sansoop.aspx">
				<span class="label">Немного теории</span>
			</a>
		</div></div>
	</div>
</body>
TPL;

	}
	
	static function head($title)
	{ 
		$doctype = Def::$doctype;
		$meta = Def::$meta;
		$style = Def::$style;
		$script = Def::$script;
		
		return <<<TPL
{$doctype}
<head>
	{$meta}
	<title>{$title}</title>
	{$style}
	{$script}
</head>
TPL;
	}

	static function table($data, $subj) 
	{
		$curr_fields = Def::$fields[$subj];
		$list_fields = array();
		
		$thead = '<thead><tr>';
		$cols = '';
		foreach ($curr_fields as $key => $props) {
			if ($props['list'] == 1) {
				$list_fields[$key] = $props;
				$name = (isset($props['ru'])) ? $props['ru'] : $props['name'];
				$name = e($name);
				$cols .= '<col class="' . $props['name'] . '">';
				$thead .= '<th>' . $name . '</th>';
			}
		}
		$thead .= '</tr></thead>' . CR;
		
		$tbody = '<tbody>';
		foreach ($data as $row) {
			$tbody .= '<tr>';
			foreach ($list_fields as $key => $props) { 
				$value = View::check_link($subj, $row, $key, $curr_fields);
				$tbody .= '<td>' . $value . '</td>';
			}
			$tbody .= '</tr>' . CR;
		}
		$tbody .= '</tbody>';
		
		return <<<TPL
<table class="sortable {$subj}">
	{$cols}
	{$thead}
	{$tbody}
</table>
TPL;
	}
	
	static function item($data, $subj) 
	{
		$curr_fields = Def::$fields[$subj];
		$data = each($data);
		$row = $data['value'];
		$item = '<table class="item"><caption>
		<a href="' . $subj . '">' . $subj . '</a>
		</caption>';
		
		foreach ($curr_fields as $key => $props) {
			$name = (!empty($props['ru'])) ? $props['ru'] : $props['name'];
			$name = e($name);
			$value = $row[$key];
			$value = nl2br(e($value));
			$item .= '<tr><td><strong>' . $name . ': </strong></td><td>' . $value . '</td></tr>' . CR;
		}
		$item .= '</table>';
		
		return <<<TPL
<div class="item {$subj}">
	{$item}
</div>
TPL;
	}
	
	static function check_link($subj, &$row, $field, &$curr_fields) 
	{
		$props = $curr_fields[$field];
		$field_value = $row[$field];
		$link_id = (isset($props['link'])) ? $props['link'] : null;
		if ($link_id) {
			$link_arr = ($link_id == 1) ? View::find_key($curr_fields, $row, 1) : array($link_id => $row[$link_id]);
			$keys = array();
			foreach ($link_arr as $key => $value) {
				$keys[] = urlencode($key) . '=' . urlencode($value);
			}
			$keys = implode('&', $keys);
			$field_value = '<a href="' . $subj . '?' . $keys . '">' . e($field_value) . '</a>';
		}
		return $field_value;
	}
	
	static function code()
	{
		$head = View::head('code: ' . Def::$env['uri']);
		$files = Def::fw_files();
		print $head . CR . '<div class="code">' 
			. '<div class="menu">' . View::menu($files['fileList'], CR) . '</div>'
			. highlight_file(Def::$env['root'] . Def::$env['uri'], true);
		#echo phpinfo();
	}
	
	static function menu(&$arr, $div = ' | ')
	{
		$menuarr = array();
		foreach ($arr as $key => $value) {
			$menuarr[] = '
			<a href="' . e($key) . '">' . e($value) . '</a>
			';
		}
		return implode($div, $menuarr);
	}
	
	static function build_main_menu()
	{
		$arr = array();
		
		foreach (Def::$subj as $key => $row) {
			$arr[$row['name']] = $row['title'];
		}
		return self::menu($arr);
	}
	
	static function find_key(&$curr_fields, &$row, $num)
	{
		$ret = array();
		foreach($curr_fields as $key => $props) {
			if ($props['key'] == $num) $ret[$key] = $row[$key];
		}
		return $ret;
	}
	
	
} //class View
